@@ -3,8 +3,9 @@ package DBIx::Class::QueryLog;
 use warnings;
 use strict;
 
-use base qw(Class::Accessor);
-__PACKAGE__->mk_accessors(qw(log current_transaction current_query));
+use base qw(DBIx::Class::Storage::Statistics);
+__PACKAGE__->mk_group_accessors(simple => qw(log current_transaction current_query passthrough));
+
 
 use Time::HiRes;
 
@@ -17,11 +18,11 @@ DBIx::Class::QueryLog - Log queries for later analysis.
 
 =head1 VERSION
 
-Version 1.0.1
+Version 1.0.2
 
 =cut
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.0.2';
 
 =head1 SYNOPSIS
 
@@ -30,21 +31,21 @@ analyze what happened in the 'session'.  It must be installed as the debugobj
 in DBIx::Class:
 
     use DBIx::Class::QueryLog;
-
-	my $schema = ... # Get your schema!
+    
+    my $schema = ... # Get your schema!
     my $ql = new DBIx::Class::QueryLog();
-	$schema->storage->debugobj($ql);
-	$schema->storage->debug(1);
-    ... # do some stuff!
+    $schema->storage->debugobj($ql);
+    $schema->storage->debug(1);
+      ... # do some stuff!
 
 Every transaction and query executed will have a corresponding Transaction
 and Query object stored in order of execution, like so:
 
-	Query
-	Query
-	Transaction
-	Query
-	
+    Query
+    Query
+    Transaction
+    Query
+
 This array can be retrieved with the log() method.  Queries executed inside
 a transaction are stored inside their Transaction object, not inside the
 QueryLog directly.
@@ -52,6 +53,9 @@ QueryLog directly.
 See L<DBIx::Class::QueryLog::Analyzer> for options on digesting the results
 of a QueryLog session.
 
+If you wish to have the QueryLog collecting results, and the normal trace
+output of SQL queries from DBIx::Class, then set C<passthru> to 1
+
 =head1 METHODS
 
 =head2 new
@@ -63,9 +67,9 @@ sub new {
     my $proto = shift();
     my $self = $proto->SUPER::new(@_);
 
-	$self->log([]);
+    $self->log([]);
 
-	return $self;
+    return $self;
 }
 
 =head2 time_elapsed
@@ -74,14 +78,14 @@ Returns the total time elapsed for ALL transactions and queries in this log.
 
 =cut
 sub time_elapsed {
-	my $self = shift();
+    my $self = shift();
 
-	my $total = 0;
-	foreach my $t (@{ $self->log() }) {
-		$total += $t->time_elapsed();
-	}
+    my $total = 0;
+    foreach my $t (@{ $self->log() }) {
+        $total += $t->time_elapsed();
+    }
 
-	return $total;
+    return $total;
 }
 
 =head2 count
@@ -93,11 +97,11 @@ sub count {
     my $self = shift();
 
     my $total = 0;
-	foreach my $t (@{ $self->log() }) {
-		$total += $t->count();
-	}
+    foreach my $t (@{ $self->log() }) {
+        $total += $t->count();
+    }
 
-	return $total;
+    return $total;
 }
 
 =head2 reset
@@ -106,9 +110,9 @@ Reset this QueryLog by removing all transcations and queries.
 
 =cut
 sub reset {
-	my $self = shift();
+    my $self = shift();
 
-	$self->log(undef);
+    $self->log(undef);
 }
 
 =head2 add_to_log
@@ -117,10 +121,10 @@ Add this provided Transaction or Query to the log.
 
 =cut
 sub add_to_log {
-	my $self = shift();
-	my $thing = shift();
+    my $self = shift();
+    my $thing = shift();
 
-	push(@{ $self->log() }, $thing);
+    push(@{ $self->log() }, $thing);
 }
 
 =head2 txn_begin
@@ -130,13 +134,14 @@ Called by DBIx::Class when a transaction is begun.
 =cut
 
 sub txn_begin {
-	my $self = shift();
+    my $self = shift();
 
-	$self->current_transaction(
-		new DBIx::Class::QueryLog::Transaction({
-			start_time => Time::HiRes::time()
-		})
-	);
+    $self->next::method(@_) if $self->passthrough;
+    $self->current_transaction(
+        new DBIx::Class::QueryLog::Transaction({
+            start_time => Time::HiRes::time()
+        })
+    );
 }
 
 =head2 txn_commit
@@ -146,18 +151,19 @@ Called by DBIx::Class when a transaction is committed.
 =cut
 
 sub txn_commit {
-	my $self = shift();
+    my $self = shift();
 
-	if(defined($self->current_transaction())) {
-		my $txn = $self->current_transaction();
-		$txn->end_time(Time::HiRes::time());
-		$txn->committed(1);
-		$txn->rolledback(0);
-		push(@{ $self->log() }, $txn);
-		$self->current_transaction(undef);
-	} else {
-		warn('Unknown transaction committed.')
-	}
+    $self->next::method(@_) if $self->passthrough;
+    if(defined($self->current_transaction())) {
+        my $txn = $self->current_transaction();
+        $txn->end_time(Time::HiRes::time());
+        $txn->committed(1);
+        $txn->rolledback(0);
+        push(@{ $self->log() }, $txn);
+        $self->current_transaction(undef);
+    } else {
+        warn('Unknown transaction committed.')
+    }
 }
 
 =head2 txn_rollback
@@ -167,18 +173,19 @@ Called by DBIx::Class when a transaction is rolled back.
 =cut
 
 sub txn_rollback {
-	my $self = shift();
+    my $self = shift();
 
-	if(defined($self->current_transaction())) {
-		my $txn = $self->current_transaction();
-		$txn->end_time(Time::HiRes::time());
-		$txn->committed(0);
-		$txn->rolledback(1);
-		$self->add_to_log($txn);
-		$self->current_transaction(undef);
-	} else {
-		warn('Unknown transaction committed.')
-	}
+    $self->next::method(@_) if $self->passthrough;
+    if(defined($self->current_transaction())) {
+        my $txn = $self->current_transaction();
+        $txn->end_time(Time::HiRes::time());
+        $txn->committed(0);
+        $txn->rolledback(1);
+        $self->add_to_log($txn);
+        $self->current_transaction(undef);
+    } else {
+        warn('Unknown transaction committed.')
+    }
 }
 
 =head2 query_start
@@ -188,17 +195,18 @@ Called by DBIx::Class when a query is begun.
 =cut
 
 sub query_start {
-	my $self = shift();
-	my $sql = shift();
-	my @params = @_;
+    my $self = shift();
+    my $sql = shift();
+    my @params = @_;
 
-	$self->current_query(
-		new DBIx::Class::QueryLog::Query({
-			start_time 	=> Time::HiRes::time(),
-			sql			=> $sql,
-			params		=> \@params,
-		})
-	);
+    $self->next::method($sql, @params) if $self->passthrough;
+    $self->current_query(
+        new DBIx::Class::QueryLog::Query({
+            start_time  => Time::HiRes::time(),
+            sql         => $sql,
+            params      => \@params,
+        })
+    );
 }
 
 =head2 query_end
@@ -208,20 +216,21 @@ Called by DBIx::Class when a query is completed.
 =cut
 
 sub query_end {
-	my $self = shift();
+    my $self = shift();
 
-	if(defined($self->current_query())) {
-		my $q = $self->current_query();
-		$q->end_time(Time::HiRes::time());
-		if(defined($self->current_transaction())) {
-			$self->current_transaction->add_to_queries($q);
-		} else {
-			$self->add_to_log($q)
-		}
-		$self->current_query(undef);
-	} else {
-		warn('Completed unknown query.');
-	}
+    $self->next::method(@_) if $self->passthrough;
+    if(defined($self->current_query())) {
+        my $q = $self->current_query();
+        $q->end_time(Time::HiRes::time());
+        if(defined($self->current_transaction())) {
+            $self->current_transaction->add_to_queries($q);
+        } else {
+            $self->add_to_log($q)
+        }
+        $self->current_query(undef);
+    } else {
+        warn('Completed unknown query.');
+    }
 }
 
 =head1 AUTHOR
